@@ -15,11 +15,11 @@
 Rcpp::List quadratic_expression(Eigen::Map<Eigen::VectorXd> X,
                                 Eigen::Map<Eigen::MatrixXd> Sigma) {
 
-    Eigen::MatrixXd x_adj(2, 1);
+    Eigen::VectorXd x_adj(2);
     x_adj.setZero(); // Set adjoints to zeros.
 
     // Initialize variable.
-    ad::VarView<double, ad::mat> x(X.data(), x_adj.data(), 2, 1);
+    ad::VarView<double, ad::vec> x(X.data(), x_adj.data(), 2);
 
     // Initialize (constant) Sigma matrix as a view.
     auto CSigma = ad::constant_view(Sigma.data(), Sigma.rows(), Sigma.cols());
@@ -27,12 +27,10 @@ Rcpp::List quadratic_expression(Eigen::Map<Eigen::VectorXd> X,
     // Quadratic expression: x^T*Sigma*x
     auto expr = ad::bind(ad::dot(ad::dot(ad::transpose(x), CSigma), x));
     // Seed
-    Eigen::MatrixXd seed(1, 1);
-    seed.setOnes(); // Usually seed is 1. DONT'T FORGET!
-    // Auto differential.
-    auto f = ad::autodiff(expr, seed.array());
+    Eigen::Array<double, 1, 1> seed(1);
+    auto f = ad::autodiff(expr, seed);
 
-    Rcpp::List res = Rcpp::List::create(Rcpp::Named("value") = f,
+    Rcpp::List res = Rcpp::List::create(Rcpp::Named("value") = f(0,0),
                                         Rcpp::Named("gradient") = x.get_adj());
 
     return res;
